@@ -302,7 +302,7 @@ void MobileConnectionWizard::introAddDevice(const NetworkManager::Device::Ptr &d
             desc.append(modemInterface->model());
         } else {
             QString deviceName = modemInterface->device();
-            Q_FOREACH (const Solid::Device &d, Solid::Device::allDevices()) {
+            for (const Solid::Device &d : Solid::Device::allDevices()) {
                 if (d.udi().contains(deviceName, Qt::CaseInsensitive)) {
                     deviceName = d.product();
                     if (!deviceName.startsWith(d.vendor())) {
@@ -382,7 +382,7 @@ void MobileConnectionWizard::introStatusChanged(NetworkManager::Status status)
 
 void MobileConnectionWizard::introAddInitialDevices()
 {
-    Q_FOREACH (const NetworkManager::Device::Ptr & n, NetworkManager::networkInterfaces()) {
+    for (const NetworkManager::Device::Ptr &n : NetworkManager::networkInterfaces()) {
         introAddDevice(n);
     }
 
