@@ -1,22 +1,8 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+// SPDX-License-Identifier: GPL-2.0+
 /* nm-l2tp-service - L2TP VPN integration with NetworkManager
  *
  * Dan Williams <dcbw@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- *
  * Copyright 2008, 2014 Red Hat, Inc.
  */
 
@@ -34,15 +20,16 @@
 #define NM_DBUS_PATH_L2TP_PPP       "/org/freedesktop/NetworkManager/l2tp/ppp"
 
 #define NM_L2TP_KEY_GATEWAY           "gateway"
+#define NM_L2TP_KEY_USER_AUTH_TYPE    "user-auth-type"
 #define NM_L2TP_KEY_USER              "user"
 #define NM_L2TP_KEY_PASSWORD          "password"
-#define NM_L2TP_KEY_USE_CERT          "use-cert"
-#define NM_L2TP_KEY_CERT_PUB          "cert-pub"
-#define NM_L2TP_KEY_CERT_CA           "cert-ca"
-#define NM_L2TP_KEY_CERT_KEY          "cert-key"
+#define NM_L2TP_KEY_DOMAIN            "domain"
+#define NM_L2TP_KEY_USER_CA           "user-ca"
+#define NM_L2TP_KEY_USER_CERT         "user-cert"
+#define NM_L2TP_KEY_USER_KEY          "user-key"
+#define NM_L2TP_KEY_USER_CERTPASS     "user-certpass"
 #define NM_L2TP_KEY_MTU               "mtu"
 #define NM_L2TP_KEY_MRU               "mru"
-#define NM_L2TP_KEY_DOMAIN            "domain"
 #define NM_L2TP_KEY_REFUSE_EAP        "refuse-eap"
 #define NM_L2TP_KEY_REFUSE_PAP        "refuse-pap"
 #define NM_L2TP_KEY_REFUSE_CHAP       "refuse-chap"
@@ -60,13 +47,30 @@
 #define NM_L2TP_KEY_LCP_ECHO_FAILURE  "lcp-echo-failure"
 #define NM_L2TP_KEY_LCP_ECHO_INTERVAL "lcp-echo-interval"
 #define NM_L2TP_KEY_UNIT_NUM          "unit"
-
+#define NM_L2TP_KEY_MACHINE_AUTH_TYPE "machine-auth-type"
+#define NM_L2TP_KEY_MACHINE_CA        "machine-ca"
+#define NM_L2TP_KEY_MACHINE_CERT      "machine-cert"
+#define NM_L2TP_KEY_MACHINE_KEY       "machine-key"
+#define NM_L2TP_KEY_MACHINE_CERTPASS  "machine-certpass"
 #define NM_L2TP_KEY_IPSEC_ENABLE      "ipsec-enabled"
-#define NM_L2TP_KEY_IPSEC_GATEWAY_ID  "ipsec-gateway-id"
-#define NM_L2TP_KEY_IPSEC_GROUP_NAME  "ipsec-group-name"
+#define NM_L2TP_KEY_IPSEC_REMOTE_ID   "ipsec-remote-id"
+#define NM_L2TP_KEY_IPSEC_GATEWAY_ID  "ipsec-gateway-id" /* deprecated, use ipsec-remote-id */
 #define NM_L2TP_KEY_IPSEC_PSK         "ipsec-psk"
 #define NM_L2TP_KEY_IPSEC_IKE         "ipsec-ike"
 #define NM_L2TP_KEY_IPSEC_ESP         "ipsec-esp"
+#define NM_L2TP_KEY_IPSEC_IKELIFETIME "ipsec-ikelifetime"
+#define NM_L2TP_KEY_IPSEC_SALIFETIME  "ipsec-salifetime"
 #define NM_L2TP_KEY_IPSEC_FORCEENCAPS "ipsec-forceencaps"
+#define NM_L2TP_KEY_IPSEC_IPCOMP      "ipsec-ipcomp"
+#define NM_L2TP_KEY_IPSEC_IKEV2       "ipsec-ikev2"
+#define NM_L2TP_KEY_IPSEC_PFS         "ipsec-pfs"
 
+/* Internal auth-dialog -> service token indicating that no secrets are required
+ * for the connection if X.509 private keys are used with no password protection.
+ */
+#define NM_L2TP_KEY_NOSECRET          "no-secret"
+
+#define NM_L2TP_AUTHTYPE_PASSWORD     "password"
+#define NM_L2TP_AUTHTYPE_TLS          "tls"
+#define NM_L2TP_AUTHTYPE_PSK          "psk"
 #endif /* NM_L2TP_SERVICE_DEFINES_H */
