@@ -34,14 +34,14 @@ class PptpSettingWidget : public SettingWidget
     Q_OBJECT
     Q_DECLARE_PRIVATE(PptpSettingWidget)
 public:
-    explicit PptpSettingWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0);
-    ~PptpSettingWidget();
+    explicit PptpSettingWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
+    ~PptpSettingWidget() override;
 
-    void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
-    void loadSecrets(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
+    void loadConfig(const NetworkManager::Setting::Ptr &setting) override;
+    void loadSecrets(const NetworkManager::Setting::Ptr &setting) override;
 
-    virtual QVariantMap setting() const;
-    virtual bool isValid() const;
+    QVariantMap setting() const override;
+    bool isValid() const override;
 
 private Q_SLOTS:
     void doAdvancedDialog();
