@@ -32,10 +32,10 @@ class SstpAuthWidget : public SettingWidget
     Q_OBJECT
     Q_DECLARE_PRIVATE(SstpAuthWidget)
 public:
-    explicit SstpAuthWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0);
-    ~SstpAuthWidget();
+    explicit SstpAuthWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
+    ~SstpAuthWidget() override;
 
-    virtual QVariantMap setting() const;
+    QVariantMap setting() const override;
 
 private:
     SstpAuthWidgetPrivate *const d_ptr;
